summaryrefslogtreecommitdiffstats
path: root/core/java/android/nfc/technology
diff options
context:
space:
mode:
authorMartijn Coenen <martijn.coenen@nxp.com>2010-12-21 11:18:52 +0100
committerNick Pelly <npelly@google.com>2011-01-05 13:30:15 +1100
commita559aa4759309606cd201e7e39844c3363a72b24 (patch)
tree779756fda5671be1f6e578b45c58181693ded583 /core/java/android/nfc/technology
parent8f49c025ca5b4ed84290fb9e5e0b7acb1c139b35 (diff)
downloadframeworks_base-a559aa4759309606cd201e7e39844c3363a72b24.zip
frameworks_base-a559aa4759309606cd201e7e39844c3363a72b24.tar.gz
frameworks_base-a559aa4759309606cd201e7e39844c3363a72b24.tar.bz2
Fix technology extra naming for IsoDep and NfcB (API part).
Change-Id: Iaa8f1b4dec5d626ffb17a33d71d2f92dd0d99636
Diffstat (limited to 'core/java/android/nfc/technology')
-rw-r--r--core/java/android/nfc/technology/IsoDep.java8
-rw-r--r--core/java/android/nfc/technology/NfcB.java26
2 files changed, 24 insertions, 10 deletions
diff --git a/core/java/android/nfc/technology/IsoDep.java b/core/java/android/nfc/technology/IsoDep.java
index 52a453f..32a7542 100644
--- a/core/java/android/nfc/technology/IsoDep.java
+++ b/core/java/android/nfc/technology/IsoDep.java
@@ -39,18 +39,18 @@ import java.io.IOException;
*/
public final class IsoDep extends BasicTagTechnology {
/** @hide */
- public static final String EXTRA_ATTRIB = "attrib";
+ public static final String EXTRA_HI_LAYER_RESP = "hiresp";
/** @hide */
public static final String EXTRA_HIST_BYTES = "histbytes";
- private byte[] mAttrib = null;
+ private byte[] mHiLayerResponse = null;
private byte[] mHistBytes = null;
public IsoDep(NfcAdapter adapter, Tag tag, Bundle extras)
throws RemoteException {
super(adapter, tag, TagTechnology.ISO_DEP);
if (extras != null) {
- mAttrib = extras.getByteArray(EXTRA_ATTRIB);
+ mHiLayerResponse = extras.getByteArray(EXTRA_HI_LAYER_RESP);
mHistBytes = extras.getByteArray(EXTRA_HIST_BYTES);
}
}
@@ -63,5 +63,5 @@ public final class IsoDep extends BasicTagTechnology {
/**
* 3B only
*/
- public byte[] getAttrib() { return mAttrib; }
+ public byte[] getHiLayerResponse() { return mHiLayerResponse; }
}
diff --git a/core/java/android/nfc/technology/NfcB.java b/core/java/android/nfc/technology/NfcB.java
index de528f8..267c94d 100644
--- a/core/java/android/nfc/technology/NfcB.java
+++ b/core/java/android/nfc/technology/NfcB.java
@@ -37,20 +37,34 @@ import android.os.RemoteException;
*/
public final class NfcB extends BasicTagTechnology {
/** @hide */
- public static final String EXTRA_ATQB = "atqb";
+ public static final String EXTRA_APPDATA = "appdata";
+ /** @hide */
+ public static final String EXTRA_PROTINFO = "protinfo";
- private byte[] mAtqb;
+ private byte[] mAppData;
+ private byte[] mProtInfo;
public NfcB(NfcAdapter adapter, Tag tag, Bundle extras)
throws RemoteException {
super(adapter, tag, TagTechnology.NFC_B);
- mAtqb = extras.getByteArray(EXTRA_ATQB);
+ mAppData = extras.getByteArray(EXTRA_APPDATA);
+ mProtInfo = extras.getByteArray(EXTRA_PROTINFO);
+ }
+
+ /**
+ * Returns the Application Data bytes from the ATQB/SENSB_RES
+ * bytes discovered at tag discovery.
+ */
+ public byte[] getApplicationData() {
+ return mAppData;
}
/**
* Returns the ATQB/SENSB_RES bytes discovered at tag discovery.
*/
- public byte[] getAtqb() {
- return mAtqb;
+ public byte[] getProtocolInfo() {
+ return mProtInfo;
}
+
}
@@ -37,20 +37,34 @@ import android.os.RemoteException;
}
/**
- * Returns the ATQB/SENSB_RES bytes discovered at tag discovery.
+ * Returns the Protocol Info bytes from the ATQB/SENSB_RES
+ * bytes discovered at tag discovery.
*/